package com.yijia.station.service;

import java.util.List;
import com.yijia.station.domain.PayOrder;

/**
 * 订单支付Service接口
 * 
 * @author yijia
 * @date 2020-12-10
 */
public interface IPayOrderService 
{
    /**
     * 查询订单支付
     * 
     * @param orderId 订单支付ID
     * @return 订单支付
     */
    public PayOrder selectPayOrderById(Long orderId);

    /**
     * 查询订单支付列表
     * 
     * @param payOrder 订单支付
     * @return 订单支付集合
     */
    public List<PayOrder> selectPayOrderList(PayOrder payOrder);

    /**
     * 新增订单支付
     * 
     * @param payOrder 订单支付
     * @return 结果
     */
    public int insertPayOrder(PayOrder payOrder);

    /**
     * 修改订单支付
     * 
     * @param payOrder 订单支付
     * @return 结果
     */
    public int updatePayOrder(PayOrder payOrder);

    /**
     * 批量删除订单支付
     * 
     * @param orderIds 需要删除的订单支付ID
     * @return 结果
     */
    public int deletePayOrderByIds(Long[] orderIds);

    /**
     * 删除订单支付信息
     * 
     * @param orderId 订单支付ID
     * @return 结果
     */
    public int deletePayOrderById(Long orderId);
}
